aboutsummaryrefslogtreecommitdiff
path: root/lib/transfer.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/transfer.c')
-rw-r--r--lib/transfer.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/lib/transfer.c b/lib/transfer.c
index 31553eb46..760e79d9f 100644
--- a/lib/transfer.c
+++ b/lib/transfer.c
@@ -1952,8 +1952,10 @@ Curl_setup_transfer(
k->exp100 = EXP100_AWAITING_CONTINUE;
k->start100 = Curl_tvnow();
- /* set a timeout for the multi interface */
- Curl_expire(data, CURL_TIMEOUT_EXPECT_100);
+ /* Set a timeout for the multi interface. Add the inaccuracy margin so
+ that we don't fire slightly too early and get denied to run. */
+ Curl_expire(data, CURL_TIMEOUT_EXPECT_100 +
+ MULTI_TIMEOUT_INACCURACY / 1000);
}
else {
if(data->state.expect100header)